@@ -4,6 +4,7 @@
 
 #include "kaldifeat/python/csrc/feature-spectrogram.h"
 
+#include <memory>
 #include <string>
 
 #include "kaldifeat/csrc/feature-spectrogram.h"
@@ -34,9 +35,15 @@ static void PybindSpectrogramOptions(py::module &m) {
            [](const PyClass &self) -> std::string { return self.ToString(); })
       .def("as_dict",
            [](const PyClass &self) -> py::dict { return AsDict(self); })
-      .def_static("from_dict", [](py::dict dict) -> PyClass {
-        return SpectrogramOptionsFromDict(dict);
-      });
+      .def_static("from_dict",
+                  [](py::dict dict) -> PyClass {
+                    return SpectrogramOptionsFromDict(dict);
+                  })
+      .def(py::pickle(
+          [](const PyClass &self) -> py::dict { return AsDict(self); },
+          [](py::dict dict) -> PyClass {
+            return SpectrogramOptionsFromDict(dict);
+          }));
 }
 
 static void PybindSpectrogram(py::module &m) {
@@ -46,7 +53,14 @@ static void PybindSpectrogram(py::module &m) {
       .def("dim", &PyClass::Dim)
       .def_property_readonly("options", &PyClass::GetOptions)
       .def("compute_features", &PyClass::ComputeFeatures, py::arg("wave"),
-           py::arg("vtln_warp"));
+           py::arg("vtln_warp"))
+      .def(py::pickle(
+          [](const PyClass &self) -> py::dict {
+            return AsDict(self.GetOptions());
+          },
+          [](py::dict dict) -> std::unique_ptr<PyClass> {
+            return std::make_unique<PyClass>(SpectrogramOptionsFromDict(dict));
+          }));
 }
 
 void PybindFeatureSpectrogram(py::module &m) {
